import { styled } from "@mui/material/styles";
import Avatar from "@mui/material/Avatar";
import MuiDrawer, { drawerClasses } from "@mui/material/Drawer";
import Box from "@mui/material/Box";
import Stack from "@mui/material/Stack";
import Typography from "@mui/material/Typography";
import MenuContent from "../MenuContent";
import OptionsMenu from "../OptionsMenu";
import React, { useEffect } from "react";
import { ArrowLeftIcon, ArrowRightIcon } from "@mui/x-date-pickers";
import { Button } from "@mui/material";
import { fetchProfile } from "../../redux/slices/authSlice";
import { AppDispatch } from "../../redux/store/store";
import { useDispatch, useSelector } from "react-redux";
import { RootState } from "../../redux/reducers";

const drawerWidth = 240;

const Drawer = styled(MuiDrawer)({
	width: drawerWidth,
	flexShrink: 0,
	boxSizing: "border-box",
	mt: 10,
	[`& .${drawerClasses.paper}`]: {
		width: drawerWidth,
		boxSizing: "border-box",
	},
});

export default function SideMenu() {
	const [open, setOpen] = React.useState(true);

	const dispatch = useDispatch<AppDispatch>();
  
  //Created by : jaanvi and Eknoor
	//date: 12-feb-25
	//Extract user profile data from Auth
	const { user } = useSelector((state: RootState) => state.auth);

	useEffect(() => {
		// Dispatch the fetchProfile thunk to fetch user profile data
		dispatch(fetchProfile());
	}, [dispatch]);

	return (
		<Drawer
			open={open}
			variant="permanent"
			anchor="left"
			sx={{
				display: {
					xs: "none",
					md: "block",
					width: open ? 250 : 80,
					transition: "all 0.5s ease",
				},
				[`& .${drawerClasses.paper}`]: {
					backgroundColor: "background.paper",
					width: open ? 250 : 80,
					transition: "all 0.5s ease",
				},
			}}
		>
			<Box
				sx={{
					display: "flex",
					justifyContent: open ? "flex-end" : "center",
					alignItems: "center",
					pt: 1.5,
					textAlign: "center",
				}}
			>
				<Button variant="text" onClick={() => setOpen(!open)}>
					{open ? <ArrowLeftIcon /> : <ArrowRightIcon />}
				</Button>
			</Box>
			<MenuContent hidden={open} />
			{/* <CardAlert /> */}
			<Stack
				direction="row"
				sx={{
					p: 2,
					gap: 1,
					alignItems: "center",
					borderTop: "1px solid",
					borderColor: "divider",
				}}
			>
				<Avatar
					sizes="small"
					alt="Riley Carter"
					src="/static/images/avatar/7.jpg"
					sx={{ width: open ? 36 : 0, height: open ? 36 : 0 }}
				/>
				<Box sx={{ mr: "auto", display: !open ? "none" : "block" }}>
					<Typography
						variant="body2"
						sx={{ fontWeight: 500, lineHeight: "16px" }}
					>
						{user?.name}
					</Typography>
					<Typography
						variant="caption"
						sx={{ color: "text.secondary" }}
					>
						{user?.email}
					</Typography>
				</Box>
				<OptionsMenu avatar={open} />
			</Stack>
		</Drawer>
	);
}
